hyperphor.alzabo.import.candel


annotated-fieldclj

(annotated-field kind field field-index enums)

dottedclj

(dotted thing)

field-indexclj

(field-index basic-atts reference-meta)

kind-fieldsclj

(kind-fields kind basic-atts)

kind-refsclj

(kind-refs kind reference-meta)

lookup-enumclj

(lookup-enum kind field enums)

ns->keyclj

(ns->key namespaced)

ns-ns->keyclj

(ns-ns->key namespaced)

produce-schemaclj

(produce-schema)

read-ednclj

(read-edn file)

read-enumsclj

(read-enums)

Returns [enums version], where enums is a map of enum names (keyword) to list of possible values

Returns [enums version], where enums is a map of enum names (keyword) to list of possible values
raw docstring

special-case-enumsclj

cljdoc builds & hosts documentation for Clojure/Script libraries