hyperphor.alzabo.schema


*dir*clj


all-fieldsclj/s

(all-fields schema kind-name)

Get all fields for a kind including inherited fields merged with local fields

Get all fields for a kind including inherited fields merged with local fields
raw docstring

clean-enum-valueclj/s

(clean-enum-value v)

clean-stringclj/s

(clean-string s)

deep-merge-fieldclj/s

(deep-merge-field parent-field child-field)

Deep merge field definitions. Child field properties override parent, but :doc strings are concatenated.

Deep merge field definitions. Child field properties override parent,
but :doc strings are concatenated.
raw docstring

enumsclj/s

(enums schema)

Get all enum names from a schema

Get all enum names from a schema
raw docstring

get-ancestorsclj/s

(get-ancestors schema kind-name)

Get all ancestors of a kind (transitive closure of parents). Returns a sequence in breadth-first order. Detects and throws on circular inheritance.

Get all ancestors of a kind (transitive closure of parents).
Returns a sequence in breadth-first order.
Detects and throws on circular inheritance.
raw docstring

get-parentsclj/s

(get-parents schema kind-name)

Get direct parent kinds of a kind

Get direct parent kinds of a kind
raw docstring

handle-includeclj

(handle-include s)

humanizeclj/s

(humanize term)

infer-enumsclj/s

(infer-enums s)

inherited-fieldsclj/s

(inherited-fields schema kind-name)

Get all fields inherited from parent kinds with deep merge. Fields from later parents override earlier ones, and local fields override all.

Get all fields inherited from parent kinds with deep merge.
Fields from later parents override earlier ones, and local fields override all.
raw docstring

inverse-fieldsclj/s


is-enum-type?clj/s

(is-enum-type? type-name schema)

Check if a type is an enum

Check if a type is an enum
raw docstring

is-reference-type?clj/s

(is-reference-type? type-name schema)

Check if a type is a reference to another kind

Check if a type is a reference to another kind
raw docstring

kind-defclj/s

(kind-def schema kind)

kindsclj/s

(kinds schema)

Get all kind names from a schema

Get all kind names from a schema
raw docstring

merge*clj/s

(merge* mcar & mcdr)

normalize-extendsclj/s

(normalize-extends extends)

Convert :extends to a vector for consistent handling. Accepts single keyword or vector of keywords.

Convert :extends to a vector for consistent handling.
Accepts single keyword or vector of keywords.
raw docstring

numeric-primitivesclj/s


path-dirclj

(path-dir p)

primitivesclj/s


read-schemaclj

(read-schema source)

reduce-old-candel-shitclj/s

(reduce-old-candel-shit s)

safe-kebab-caseclj/s

(safe-kebab-case s)

strict-keysclj/smacro

(strict-keys & {:keys [req req-un opt opt-un]})

struct-parentclj/s

(struct-parent struct thing)

validate-inheritanceclj/s

(validate-inheritance schema)

Validate all inheritance relationships in a schema

Validate all inheritance relationships in a schema
raw docstring

validate-no-cyclesclj/s

(validate-no-cycles schema kind-name)

Check for circular inheritance in a kind

Check for circular inheritance in a kind
raw docstring

validate-parent-existsclj/s

(validate-parent-exists schema kind-name)

Check that all parent kinds exist in the schema

Check that all parent kinds exist in the schema
raw docstring

validate-schemaclj/s

(validate-schema schema)

cljdoc builds & hosts documentation for Clojure/Script libraries