hyperphor.alzabo.search.core


get-schemacljs

(get-schema)

highlight-namecljs

(highlight-name name typed)

(kind-link kind & [body])

re-substitutecljs

(re-substitute re s subfn)

Modeled on re-seq, but returns a list based on substrings, with subfn applied to substrings that match re

Modeled on re-seq, but returns a list based on substrings, with subfn applied to substrings that match re
raw docstring

render-itemcljs

(render-item [type & params] user-string)

runcljs

(run)

uicljs

(ui)

cljdoc builds & hosts documentation for Clojure/Script libraries