Generate example data for Alzabo schemas
Generate example data for Alzabo schemas
Context for data generation including generated entities and configuration
Context for data generation including generated entities and configuration
(add-entity! kind entity)Add a generated entity to the context
Add a generated entity to the context
(add-kind kind obs)(context-string object)(determine-generation-order schema)Determine the order to generate entities based on field dependencies. Kinds that are referenced by others are generated first.
Determine the order to generate entities based on field dependencies. Kinds that are referenced by others are generated first.
(generate-entities kind
schema
&
{:keys [count context kind-modifier] :as params})Ask LLM to generate entities based on schema. context is a related object (eg a Band for generating Songs) kind-modifier is text to add to kind/description (eg "fictional")
Ask LLM to generate entities based on schema. context is a related object (eg a Band for generating Songs) kind-modifier is text to add to kind/description (eg "fictional")
(generate-sample-data schema
&
{:keys [entity-counts llm-enabled? seed]
:or {entity-counts {} llm-enabled? true seed 42}})Generate sample data for an entire schema
Generate sample data for an entire schema
(get-entities kind)Get all entities of a given kind
Get all entities of a given kind
(kind-dependencies schema kind-name)Get the kinds that a given kind depends on (via field references)
Get the kinds that a given kind depends on (via field references)
(object-label obj)(regularize x)(reset-context! config)Reset the generation context
Reset the generation context
(topological-sort schema)Topological sort of kinds based on dependencies. Returns a sequence of kinds in dependency order (dependencies first). Handles cycles by breaking them arbitrarily.
Topological sort of kinds based on dependencies. Returns a sequence of kinds in dependency order (dependencies first). Handles cycles by breaking them arbitrarily.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |