(all-fields schema kind-name)Get all fields for a kind including inherited fields merged with local fields
Get all fields for a kind including inherited fields merged with local fields
(clean-enum-value v)(clean-string s)(deep-merge-field parent-field child-field)Deep merge field definitions. Child field properties override parent, but :doc strings are concatenated.
Deep merge field definitions. Child field properties override parent, but :doc strings are concatenated.
(enums schema)Get all enum names from a schema
Get all enum names from a schema
(get-ancestors schema kind-name)Get all ancestors of a kind (transitive closure of parents). Returns a sequence in breadth-first order. Detects and throws on circular inheritance.
Get all ancestors of a kind (transitive closure of parents). Returns a sequence in breadth-first order. Detects and throws on circular inheritance.
(get-parents schema kind-name)Get direct parent kinds of a kind
Get direct parent kinds of a kind
(handle-include s)(humanize term)(infer-enums s)(inherited-fields schema kind-name)Get all fields inherited from parent kinds with deep merge. Fields from later parents override earlier ones, and local fields override all.
Get all fields inherited from parent kinds with deep merge. Fields from later parents override earlier ones, and local fields override all.
(is-enum-type? type-name schema)Check if a type is an enum
Check if a type is an enum
(is-reference-type? type-name schema)Check if a type is a reference to another kind
Check if a type is a reference to another kind
(kind-def schema kind)(kinds schema)Get all kind names from a schema
Get all kind names from a schema
(merge* mcar & mcdr)(normalize-extends extends)Convert :extends to a vector for consistent handling. Accepts single keyword or vector of keywords.
Convert :extends to a vector for consistent handling. Accepts single keyword or vector of keywords.
(path-dir p)(read-schema source)(reduce-old-candel-shit s)(safe-kebab-case s)(strict-keys & {:keys [req req-un opt opt-un]})(struct-parent struct thing)(validate-inheritance schema)Validate all inheritance relationships in a schema
Validate all inheritance relationships in a schema
(validate-no-cycles schema kind-name)Check for circular inheritance in a kind
Check for circular inheritance in a kind
(validate-parent-exists schema kind-name)Check that all parent kinds exist in the schema
Check that all parent kinds exist in the schema
(validate-schema schema)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |