(get-schema)(highlight-name name typed)(kind-link kind & [body])(re-substitute re s subfn)Modeled on re-seq, but returns a list based on substrings, with subfn applied to substrings that match re
Modeled on re-seq, but returns a list based on substrings, with subfn applied to substrings that match re
(render-item [type & params] user-string)(run)(ui)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |